--
-- Full Stop
--
-- # Author:  Naduweisstschon
-- # date: 06.04.2019
--

FullStop = {}

function FullStop.prerequisitesPresent(specializations)
  return SpecializationUtil.hasSpecialization(Pipe, specializations)
    and SpecializationUtil.hasSpecialization(Combine, specializations)
    and SpecializationUtil.hasSpecialization(FillUnit, specializations)
    and SpecializationUtil.hasSpecialization(Dischargeable, specializations)
end

function FullStop.registerEventListeners(vehicleType)
  SpecializationUtil.registerEventListener(vehicleType, "onUpdate", FullStop)
end

function FullStop:onUpdate(dt)
  local spec = self.spec_fullStop
  local fillLevel = self:getFillUnitFillLevelPercentage(self:getCurrentDischargeNode().fillUnitIndex)

  -- Combine is stopped
  if spec.stopped then
    
    if fillLevel < 1 then
      spec.stopped = false
    end

    if self:getLastSpeed() <= 0.1 then
      -- Hold the brakes for a little longer, in case the driver
      -- is holding the gas pedal and hasn't noticed, that the
      -- combine is full.
      spec.stopTime = spec.stopTime + dt
    end

    if spec.stopTime < 2000 then
      self:setBrakeLightsVisibility(true)
    
      for k, wheel in pairs(self:getWheels()) do
        setWheelShapeProps(wheel.node, wheel.wheelShape, 0, 999, wheel.steeringAngle, wheel.rotationDamping)
      end
    end

    return
  end

  if self.spec_enterable.isEntered and self.spec_drivable.isActive then

    if not spec.stopped and fillLevel == 1 then
      self.spec_drivable.cruiseControl.state = 0
      self:setPipeState(2)
      spec.stopped = true
      spec.stopTime = 0
    end

  end
end
